Module: Rawfeed
- Defined in:
- lib/rawfeed/plugin/with_class.rb,
lib/rawfeed/root.rb,
lib/rawfeed/build.rb,
lib/rawfeed/core/utils.rb,
lib/rawfeed/command/cli.rb,
lib/rawfeed/core/layout.rb,
lib/rawfeed/content/page.rb,
lib/rawfeed/content/post.rb,
lib/rawfeed/core/version.rb,
lib/rawfeed/build/cleaner.rb,
lib/rawfeed/command/tools.rb,
lib/rawfeed/content/draft.rb,
lib/rawfeed/content/pixel.rb,
lib/rawfeed/build/minifier.rb,
lib/rawfeed/command/backup.rb,
lib/rawfeed/content/donate.rb,
lib/rawfeed/content/resume.rb,
lib/rawfeed/content/contact.rb,
lib/rawfeed/plugin/datelang.rb,
lib/rawfeed/content/licenses.rb,
lib/rawfeed/command/installer.rb,
lib/rawfeed/plugin/csp_filters.rb,
lib/rawfeed/plugin/reading_time.rb,
lib/rawfeed/build/image_minifier.rb
Overview
TODO: Note: If you have an inline script, generate a hash of it for CSP
By default, this functionality is not being used because the project does not have any
inline scripts. Module disabled!
Defined Under Namespace
Modules: AddClassHtml, Build, CspFilters, Datelang, ReadingTimeFilter, Tools Classes: Backup, CLI, Contact, Donate, Draft, Installer, Layout, Licenses, Page, Pixel, Post, PostList, Resume, Utils
Constant Summary collapse
- ROOT =
File.("../..", __dir__)
- CONFIG =
{ 'DRAFTS_DIR' => File.join(".", "_drafts"), 'POSTS_DIR' => File.join(".", "_posts"), 'PIXELS_DIR' => File.join(".", "_pixels"), 'PAGES_DIR' => File.join(".", "_pages"), 'RESUME_DIR' => File.join(".", "_data"), 'CONFIG_YML' => File.join(".", "_config.yml"), 'markdown_extension' => "md" }
- VERSION =
"1.0.0"